#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate
version:              1.3.5
visibility:           public
id:                   authenticate-1.3.5-17shCHSUjCeKaq9hwMJQ4p
key:                  authenticate-1.3.5-17shCHSUjCeKaq9hwMJQ4p
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  496a56b3d77456f9b46f7602925b478a
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-8.10.5/site-local/authenticate-1.3.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/authenticate-1.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/authenticate-1.3.5
hs-libraries:         HSauthenticate-1.3.5-17shCHSUjCeKaq9hwMJQ4p
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE containers-0.6.4.1
    html-conduit-1.3.2.1-3v0BrP1D0YOKoOLTikhwHf
    http-conduit-2.3.8-EHVj4SxGcYE5sNggtZCndH
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    network-uri-2.6.4.1-4m8gp52oIfHLdE9VhQrWxs
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    xml-conduit-1.9.1.1-5pCpotf51DzBhLZtCry6QK

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

